<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	
<xsl:import href="misc.xslt"/>
<xsl:output omit-xml-declaration="yes"/>
	
<xsl:template match="/">
<xsl:for-each select="site">
<xsl:for-each select="database">
<xsl:variable name="databaseName">
<xsl:call-template name="createSQLId">
<xsl:with-param name="name" select="@id"/>
</xsl:call-template>
</xsl:variable>

#
# delete existing database and recreate it
#

DROP DATABASE IF EXISTS <xsl:value-of select="$databaseName"/>;
CREATE DATABASE <xsl:value-of select="$databaseName"/>;
USE <xsl:value-of select="$databaseName"/>;

</xsl:for-each>

#
# create structure of table ID
#

DROP TABLE IF EXISTS ID;
CREATE TABLE ID(
ID_ID INT(12) NOT NULL auto_increment,
TABLE_MAPPING_ID INT(12) NOT NULL default '0',
PRIMARY KEY (ID_ID)
) TYPE=MyISAM;


#
# create structure of table TABLE_MAPPING
#

DROP TABLE IF EXISTS TABLE_MAPPING;
CREATE TABLE TABLE_MAPPING(
TABLE_MAPPING_ID INT(12) NOT NULL default '0',
TABLE_NAME VARCHAR(255) NOT NULL default '',
PRIMARY KEY (TABLE_MAPPING_ID)
) TYPE=MyISAM;

INSERT INTO ID (TABLE_MAPPING_ID) VALUES ('1');
INSERT INTO TABLE_MAPPING (TABLE_MAPPING_ID,TABLE_NAME) VALUES (LAST_INSERT_ID(),'TABLE_MAPPING');


<xsl:for-each select="table">
<xsl:variable name="tableName">
<xsl:call-template name="createSQLId">
<xsl:with-param name="name" select="@id"/>
</xsl:call-template>
</xsl:variable>

#
# create structure of table <xsl:value-of select="$tableName"/>
#

DROP TABLE IF EXISTS <xsl:value-of select="$tableName"/>;
CREATE TABLE <xsl:value-of select="$tableName"/> (
<xsl:value-of select="$tableName"/>_ID INT(12) NOT NULL,
<xsl:for-each select="field">
<xsl:variable name="fieldName">
<xsl:call-template name="createSQLId">
<xsl:with-param name="name" select="@id"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="fieldType">
<xsl:variable name="xmlType">
<xsl:call-template name="createTypeId"/>
</xsl:variable>
<xsl:choose>
	<xsl:when test="$xmlType='String'">
	<xsl:choose>
		<xsl:when test="concat('',number(string/@maxLength))='NaN'">VARCHAR(255)</xsl:when>
		<xsl:when test="string/@maxLength>255">TEXT</xsl:when>
		<xsl:otherwise>	<xsl:value-of select="concat('VARCHAR(',string/@maxLength,')')"/></xsl:otherwise>
	</xsl:choose>
	<xsl:if test="String/@defaultValue!=''"><xsl:value-of select="concat('default ',string/@defaultValue)"/></xsl:if>
	</xsl:when>
	<xsl:when test="$xmlType='Integer'">INT(12) 	<xsl:if test="integer/@defaultValue!=''"><xsl:value-of select="concat('default ',integer/@defaultValue)"/></xsl:if></xsl:when>
	<xsl:when test="$xmlType='Date'">DATE</xsl:when>
	<xsl:when test="$xmlType='Double'"/>
</xsl:choose>
<xsl:if test="@notNull='true'"> NOT NULL</xsl:if>
</xsl:variable>
<xsl:value-of select="concat($fieldName,' ',$fieldType,',',$crlf)"/>
</xsl:for-each>PRIMARY KEY (<xsl:value-of select="$tableName"/>_ID)
) TYPE=MyISAM;


INSERT INTO ID (TABLE_MAPPING_ID) VALUES ('1');
INSERT INTO TABLE_MAPPING (TABLE_MAPPING_ID,TABLE_NAME) VALUES (LAST_INSERT_ID(),'<xsl:value-of select="$tableName"/>');



</xsl:for-each>
</xsl:for-each>
</xsl:template>
</xsl:stylesheet>
